Welcome to ClientVPS Mirrors

Help for package objectremover
Title: 'RStudio' Addin for Removing Objects from the Global Environment Based on Patterns and Object Type
Version: 0.8.1
Maintainer: Alan Yeung <alan_y987@hotmail.com>
Description: An 'RStudio' addin to assist with removing objects from the global environment. Features include removing objects according to name patterns and object type. During the course of an analysis, temporary objects are often created and this tool assists with removing them quickly. This can be useful when memory management within 'R' is important.
Depends: R (≥ 3.0.0)
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://github.com/alan-y/objectremover
BugReports: https://github.com/alan-y/objectremover/issues
RoxygenNote: 7.1.1
Imports: shiny, miniUI,
Suggests: rstudioapi
NeedsCompilation: no
Packaged: 2021-08-15 19:58:43 UTC; alan_
Author: Alan Yeung ORCID iD [aut, cre]
Repository: CRAN
Date/Publication: 2021-08-16 09:40:02 UTC

object_remove

Description

Removes objects from the global environment according to a pattern for easy use as an RStudio addin

Usage

object_remove()

Examples

if (interactive()) {
  object_remove()
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.